@@ -7,8 +7,10 @@ STATE_CONNECTED = 2
 
 REGISTERED_CALL_URI = 0
 REGISTERED_CALL_CALLBACK = 1
+REGISTERED_CALL_QUEUE_NAME = 2
 SUBSCRIPTION_TOPIC = 0
 SUBSCRIPTION_CALLBACK = 1
+SUBSCRIPTION_QUEUE_NAME= 2
 
 TRANSPORT_REGISTRY = {}
 
@@ -27,3 +29,8 @@ RAWSOCKET_HANDSHAKE_ERRORS = {
 RAWSOCKET_MESSAGE_TYPE_REGULAR = 0
 RAWSOCKET_MESSAGE_TYPE_PING = 1
 RAWSOCKET_MESSAGE_TYPE_PONG = 2
+
+
+EV_INIT = 1
+EV_EXIT = 2
+EV_MAX_UPDATED = 3
